/// <reference path="../../types/global.d.ts" />
import { ZegoMediaElement } from "../../types";
import { BaseCenter } from "../common";
import { AudioMixConfig, PlayOption, PublishStreamConstraints, ZegoMediaStreamConstraints } from "../common/zego.entity";
import { MediaUtil } from "../util/mediaUtil";
import type { ZegoStreamView } from "zego-express-engine-webrtc/sdk/code/zh/ZegoStreamView.web";
export declare class ZegoClient extends BaseCenter {
    constructor();
    static screenShotReady: boolean;
    static mediaRecorder: MediaRecorder;
    static recordedBlobs: Blob[];
    static recordType: string;
    enableCamera(localVideo: HTMLMediaElement, enable: boolean): boolean;
    enableMicrophone(localVideo: HTMLMediaElement, enable: boolean): boolean;
    setLocalAudioOutput(localVideo: HTMLMediaElement, audioOutput: string): boolean;
    setPlayAudioOutput(streamid: string, audioOutput: string): boolean;
    setCustomSignalUrl(signalUrl: Array<string>): void;
    setQualityMonitorCycle(timeInMs: number): void;
    startPlayingByStreamView(streamID: string, playOption?: PlayOption): Promise<ZegoStreamView>;
    startPlayingStream(streamID: string, remoteVideo: HTMLMediaElement, audioOutput?: string, playOption?: PlayOption): boolean;
    private _startPlayingStream;
    stopPlayingStream(streamid: string): boolean;
    startPreviewByStreamView(mediaStreamConstraints: ZegoMediaStreamConstraints): Promise<ZegoStreamView>;
    startPreview(localVideo: HTMLMediaElement, mediaStreamConstraints: ZegoMediaStreamConstraints, success: Function, error: Function): boolean;
    private createStream;
    stopPreview(localVideo: HTMLMediaElement | ZegoStreamView): boolean;
    startPublishingStream(streamid: string, localVideo: HTMLMediaElement | ZegoStreamView, extraInfo?: string, playOption?: PlayOption): boolean;
    stopPublishingStream(streamid: string): boolean;
    preloadEffect(id: number, effectUrl: string, callBack?: Function): void;
    playEffect(audioMixConfig: AudioMixConfig, start?: Function, end?: Function): void;
    pauseEffect(streamid: string): void;
    stopEffect(streamid: string): void;
    resumeEffect(streamid: string): void;
    unloadEffect(effecId: number): boolean;
    startMixingAudio(streamID: string, audio: HTMLMediaElement | HTMLMediaElement[], replace?: boolean): boolean;
    stopMixingAudio(streamID: string, audio?: Array<HTMLMediaElement>): boolean;
    setMixingAudioVolume(streamid: string, volume: number): boolean;
    startScreenShotChrome(callBack: (suc: boolean, stream: MediaStream | null, err?: string) => void): void;
    startScreenSharingByStreamView(screenConfig: {
        width?: number;
        height?: number;
        frameRate?: number;
        bitRate?: number;
        displaySurface?: string;
    }, audio: boolean): Promise<ZegoStreamView>;
    startScreenSharing(screenConfig: {
        width?: number;
        height?: number;
        frameRate?: number;
        bitRate?: number;
        displaySurface?: string;
    }, audio: boolean, callBack: (suc: boolean, stream: MediaStream | null, err?: any) => void): void;
    startScreenShotFirFox(screenConfig: {
        width?: number;
        height: number;
        frameRate?: number;
        bitRate?: number;
    }, mediaSource: "screen" | "application" | "window", audio: boolean, callBack: (suc: boolean, stream: MediaStream | null) => void): void;
    stopScreenShot(stream: MediaStream): void;
    switchDevice(type: "audio" | "video", localVideo: HTMLMediaElement, deviceId: string, success: Function, error: Function): void;
    filterStreamList(streamId?: string): any[] | undefined;
    setPublishStreamConstraints(streamID: string, constraints: PublishStreamConstraints, success: Function, error: Function): void;
    setSoundLevelDelegate(bool: boolean, timeInMs?: number): void;
    /**
     * 设置关闭摄像头时所推静态图片的路径
     *
     * Note: 支持版本：2.14.0 及以上
     *
     * Note: 详情描述：设置关闭摄像头时所推静态图片的路径。开始正常推流后，调用 mutePublishStreamVideo(true) 时会开始推静态图片，调用 mutePublishStreamVideo(false) 时会结束推静态图片。
     *
     * Note: 业务场景：开发者希望关闭摄像头时，显示静态图片。例如，主播退后台的时候，会主动关闭摄像头，此时观众侧需要展示主播暂时离开的图片。
     *
     * Note: 调用时机：创建流之后，关闭摄像头前调用本 API 进行参数配置，在关闭摄像头后，即可推静态图片。
     *
     * @param filePath 图片路径
     * @param stream mediaStream对象，可在预览成功后通过 HTMLMediaElement 的 srcObject获取
     */
    setDummyCaptureImagePath(filePath: string, stream: MediaStream): Promise<boolean>;
    static supportDetection(success: Function, error: Function): void;
    enumDevices(deviceInfoCallback: Function, error: Function): void;
    static enumDevices(deviceInfoCallback: Function, error: Function): void;
    static getAudioInfo(el: HTMLVideoElement | HTMLAudioElement, errCallBack: (param: any) => void, option?: {
        type: string;
        bufferSize?: number;
        channels?: number;
        sampleBit?: 8 | 16;
        sampleRate: number;
    }): MediaUtil | null;
    private static handleDataAvailable;
    static startRecord(el: ZegoMediaElement, constraints?: {
        audio?: false;
        audioInput?: string;
    }, callBack?: (err?: any) => void): Promise<void>;
    static stopRecord(): void;
    static resumeRecord(): void;
    static pauseRecord(): void;
    static saveRecord(name?: string): string | undefined;
    static resumeRecordAudio(): void;
    static pauseRecordAudio(): void;
    static getRecordAudio(): string | undefined;
    static takeSnapShot(el: HTMLVideoElement, img: HTMLImageElement): void;
    static saveSnapShot(el: HTMLVideoElement, name: string): void;
    enableDualStream(localVideo: HTMLMediaElement): void;
    setLowStreamParameter(localVideo: HTMLMediaElement, config: {
        width: number;
        height: number;
        frameRate: number;
        bitRate: number;
    }): void;
}
